@@ -3,8 +3,6 @@ import importlib
 import logging
 from datetime import datetime
 
-import pycountry
-
 from .classes.app import AppInformation
 from .classes.channel import ChannelInformation
 from .classes.channelepg import ChannelEPGInformation
@@ -14,21 +12,11 @@ from .classes.favourite import FavouriteInformation
 from .classes.media import MediaInformation
 from .classes.programme import Programme
 from .classes.recordings import RecordingsInformation
-from .const import (
-    ALLRECORDINGS,
-    COMMANDS,
-    CURRENT_TRANSPORT_STATE,
-    EPG_ERROR_NO_DATA,
-    EPG_ERROR_PAST_END,
-    SKY_STATE_NOMEDIA,
-    SKY_STATE_OFF,
-    SKY_STATE_ON,
-    SKY_STATE_PAUSED,
-    SKY_STATE_PLAYING,
-    SKY_STATE_STANDBY,
-    SKY_STATE_STOPPED,
-    SKY_STATE_TRANSITIONING,
-)
+from .const import (ALLRECORDINGS, COMMANDS, CURRENT_TRANSPORT_STATE,
+                    EPG_ERROR_NO_DATA, EPG_ERROR_PAST_END, SKY_STATE_NOMEDIA,
+                    SKY_STATE_OFF, SKY_STATE_ON, SKY_STATE_PAUSED,
+                    SKY_STATE_PLAYING, SKY_STATE_STANDBY, SKY_STATE_STOPPED,
+                    SKY_STATE_TRANSITIONING)
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -357,9 +345,8 @@ class SkyQRemote:
     def _import_country(self, country_code):
         """Work out the country for the Country Code."""
         try:
-            country = pycountry.countries.get(alpha_3=country_code).alpha_2.casefold()
             skyq_country = importlib.import_module(
-                f"pyskyqremote.country.remote_{country}"
+                f"pyskyqremote.country.remote_{country_code.lower()}"
             ).SkyQCountry
 
         except (AttributeError, ModuleNotFoundError) as err:
@@ -371,7 +358,7 @@ class SkyQRemote:
             )
 
             skyq_country = importlib.import_module(
-                "pyskyqremote.country.remote_" + "gb"
+                "pyskyqremote.country.remote_" + "gbr"
             ).SkyQCountry
 
         return skyq_country
